from ngsolve import *
from netgen.geom2d import SplineGeometry

geometry = SplineGeometry()
pnts = [ (0,0), (1,0), (1,0.5), (1,1), (0,1), (0, 0.5)]
pnums = [geometry.AppendPoint(*p) for p in pnts]
# start-point, end-point, boundary-condition, domain on left side, domain on right side:
lines = [ (pnums[0],pnums[1],"gammaDd",2,0), (pnums[1],pnums[2],"gammaDd",2,0),
(pnums[2],pnums[3],"gammaS",1,0), (pnums[3],pnums[4],"gammaS",1,0),
(pnums[4],pnums[5],"gammaS",1,0),
(pnums[5],pnums[0],"gammaDd",2,0), (pnums[5],pnums[2],"gammaSD",1,2)]
for p1,p2,bc,left,right in lines:
    geometry.Append( ["line", p1, p2], bc=bc, leftdomain=left, rightdomain=right)


geometry.SetMaterial(1, "dom1")
geometry.SetMaterial(2, "dom2")

mesh = Mesh(geometry.GenerateMesh(maxh=0.1))
Draw(mesh)

V1 = HDiv(mesh, order=2, dirichlet="gammaSD")
V2 = HDiv(mesh, order=2, dirichlet="gammaSD", definedon = "dom2")
V3 = Compress(V2)

print("V1 ndof = ", V1.ndof)
print("V1 fdofs = ", sum(V1.FreeDofs()))
print("V2 ndof = ", V2.ndof)
print("V2 fdofs = ", sum(V2.FreeDofs()))
print("V3 ndof = ", V3.ndof)
print("V3 fdofs = ", sum(V3.FreeDofs()))
